
#ifndef LIBDRAWYGUI_EXPORT_H
#define LIBDRAWYGUI_EXPORT_H

#ifdef LIBDRAWYGUI_STATIC_DEFINE
#  define LIBDRAWYGUI_EXPORT
#  define LIBDRAWYGUI_NO_EXPORT
#else
#  ifndef LIBDRAWYGUI_EXPORT
#    ifdef libdrawygui_EXPORTS
        /* We are building this library */
#      define LIBDRAWYGUI_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define LIBDRAWYGUI_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef LIBDRAWYGUI_NO_EXPORT
#    define LIBDRAWYGUI_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef LIBDRAWYGUI_DEPRECATED
#  define LIBDRAWYGUI_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef LIBDRAWYGUI_DEPRECATED_EXPORT
#  define LIBDRAWYGUI_DEPRECATED_EXPORT LIBDRAWYGUI_EXPORT LIBDRAWYGUI_DEPRECATED
#endif

#ifndef LIBDRAWYGUI_DEPRECATED_NO_EXPORT
#  define LIBDRAWYGUI_DEPRECATED_NO_EXPORT LIBDRAWYGUI_NO_EXPORT LIBDRAWYGUI_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef LIBDRAWYGUI_NO_DEPRECATED
#    define LIBDRAWYGUI_NO_DEPRECATED
#  endif
#endif

#endif /* LIBDRAWYGUI_EXPORT_H */
